@@ -180,6 +180,9 @@ try:
     from progress.bar import Bar as IncrementalBar
   del sys
   class _ProgressBar(IncrementalBar):
+    # Also display (even if not a tty).
+    # Could be a jupyter notebook, which can still benefit from a progress bar.
+    check_tty = False
     # Define a custom ETA, which prints the elapsed time at the end.
     @property
     def myeta(self):
@@ -267,10 +270,11 @@ class BufferBase (object):
   def _cmdline_args (cls, parser):
     from fstd2nc import __version__
     from argparse import SUPPRESS
+    from sys import stdout
     parser.add_argument('--version', action='version', version=__version__)
     group = parser.add_mutually_exclusive_group()
     _('Display a progress bar during the conversion, if the "progress" module is installed.')
-    group.add_argument('--progress', action='store_true', default=True, help=SUPPRESS)
+    group.add_argument('--progress', action='store_true', default=stdout.isatty(), help=SUPPRESS)
     group.add_argument('--no-progress', action='store_false', dest='progress', help=_('Disable the progress bar.'))
     group = parser.add_mutually_exclusive_group()
     group.add_argument('--minimal-metadata', action='store_true', default=True, help=_("Don't include RPN record attributes and other internal information in the output metadata.")+" "+_("This is the default behaviour."))
@@ -530,7 +534,10 @@ class BufferBase (object):
     with warnings.catch_warnings():
       warnings.simplefilter("ignore")
       from fstd2nc.extra import structured_array
-      headers = structured_array(self._headers)
+      headers = dict()
+      for key in list(self._var_id)+['ip1','ip2','ip3','ig1','ig2','ig3','ig4']:
+        headers[key] = self._headers[key]
+      headers = structured_array(headers)
       meta_keys = headers.data[meta_mask][list(self._var_id)+['ip1','ip2','ip3','ig1','ig2','ig3','ig4']]
     meta_keys, ind = np.unique(meta_keys, return_index=True)
     meta_recids = meta_recids[ind]
@@ -545,6 +552,7 @@ class BufferBase (object):
     if len(filenames) == 0:
       filenames = self._files[0:1]
     # Open these files and link them together
+    self._meta_filenames = filenames  # Store this for further hacking.
     self._meta_funit = fstopenall(filenames, FST_RO)
 
 
@@ -687,7 +695,7 @@ class BufferBase (object):
         atts['coordinates'] = coords
 
       # Check if we have full coverage along all axes.
-      have_data = [k >= 0 for k in record_id.flatten()]
+      have_data = (record_id.flatten() >= 0)
       if not np.all(have_data):
         warn (_("Missing some records for %s.")%nomvar)
 
@@ -763,7 +771,10 @@ class BufferBase (object):
         if n in self._ignore_atts: continue
         # Ignore columns which are masked out.
         # https://stackoverflow.com/questions/29530232/python-pandas-check-if-any-value-is-nan-in-dataframe
-        if var_records[n].isnull().values.any(): continue
+        try:
+          if np.isnan(var_records[n].values[0]): continue
+        except TypeError:
+          if var_records[n].values[0] is None: continue
         # Get the unique values, in order.
         # Coerce back to original dtype, since masked columns get upcasted to
         # float64 in pandas.DataFrame.from_records.
@@ -774,27 +785,26 @@ class BufferBase (object):
           # For instance, pandas < 0.23 can't convert between datetime64 with
           # different increments ([ns] and [s]).
           column = var_records[n]
-        cat = pd.Categorical(column)
         # Is this column an outer axis?
         if n in self._outer_axes:
-          values = tuple(cat.categories)
+          values, indices[n] = np.unique(column, return_inverse=True)
+          values = tuple(values)
           if (n,values) not in known_axes:
             known_axes[(n,values)] = _axis_type(name = n, atts = OrderedDict(),
                                    array = np.array(values,dtype=column.dtype))
           axes[n] = known_axes[(n,values)]
-          indices[n] = cat.codes
           # Is this also an axis for an auxiliary coordinate?
           for coordname,coordaxes in self._outer_coords.items():
             if n in coordaxes:
               coordnames.append(coordname)
               coord_axes.setdefault(coordname,OrderedDict())[n] = axes[n]
-              coord_indices.setdefault(coordname,OrderedDict())[n] = cat.codes
+              coord_indices.setdefault(coordname,OrderedDict())[n] = indices[n]
         # Otherwise, does it have a consistent value?
         # If so, can add it to the metadata.
         # Ignore outer coords, since the value is already encoded elsewhere.
-        elif len(cat.categories) == 1 and n not in self._outer_coords:
+        elif np.all(column.values == column.values[0]) and n not in self._outer_coords:
           try:
-            v = cat[0]
+            v = column.values[0]
             # Python3: convert bytes to str.
             if isinstance(v,bytes): v = str(v.decode())
             # Trim string attributes (remove whitespace padding).
@@ -827,7 +837,10 @@ class BufferBase (object):
       coords = []
       for n in coordnames:
         # Ignore auxiliary coordinates which are masked out.
-        if var_records[n].isnull().values.any(): continue
+        try:
+          if np.isnan(var_records[n].values[0]): continue
+        except TypeError:
+          if var_records[n].values[0] is None: continue
         # Unique key for this coordinate
         key = (n,tuple(coord_axes[n].items()))
         # Arrange the coordinate values in the appropriate location.
@@ -847,7 +860,7 @@ class BufferBase (object):
 
 
       # Check if we have full coverage along all axes.
-      have_data = [k >= 0 for k in record_id.flatten()]
+      have_data = (record_id.flatten() >= 0)
       if not np.all(have_data):
         warn (_("Missing some records for %s.")%nomvar)
 
@@ -983,7 +996,7 @@ class BufferBase (object):
       return fstluk (key, dtype, rank, dataArray)
 
   # How to decode the data from a raw binary array.
-  def _decode (self, data):
+  def _decode (self, data, unused):
     from fstd2nc.extra import decode
     nbits = int(data[0x0b])
     datyp = int(data[0x13])
